@@ -18,8 +18,8 @@ running Editra.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: Editra.py 69449 2011-10-18 16:43:34Z CJP $"
-__revision__ = "$Revision: 69449 $"
+__svnid__ = "$Id: Editra.py 70495 2012-02-01 21:57:22Z CJP $"
+__revision__ = "$Revision: 70495 $"
 
 #--------------------------------------------------------------------------#
 # Dependencies
@@ -111,7 +111,8 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         if ed_glob.SINGLE:
             # Setup the instance checker
             instance_name = u"%s-%s" % (self.GetAppName(), wx.GetUserId())
-            self._instance = wx.SingleInstanceChecker(instance_name)
+            lockpath = wx.StandardPaths.Get().GetTempDir()
+            self._instance = wx.SingleInstanceChecker(instance_name, path=lockpath)
             if self._instance.IsAnotherRunning():
                 try:
                     opts, args = ProcessCommandLine()
@@ -493,8 +494,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
 
     def OnActivate(self, evt):
         """Activation Event Handler
-        @param evt: event that called this handler
-        @type evt: wx.ActivateEvent
+        @param evt: wx.ActivateEvent
 
         """
         if evt.GetActive():
@@ -513,7 +513,8 @@ class Editra(wx.App, events.AppEventHandlerMixin):
 
     def OnExit(self, evt=None, force=False):
         """Handle application exit request
-        @param evt: event that called this handler
+        @keyword evt: event that called this handler
+        @keyword force: Force an exit
 
         """
         e_id = -1
@@ -594,6 +595,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
     def OpenNewWindow(self, fname=u'', caller=None):
         """Open a new window
         @keyword fname: Open a file in the new window
+        @keyword caller: MainWindow that called to open this one
         @return: the new window
 
         """
@@ -954,7 +956,7 @@ def PrintHelp(err=None):
         sys.stderr.write(err + os.linesep)
 
     print(("Editra - %s - Developers Text Editor\n"
-       "Cody Precord (2005-2010)\n\n"
+       "Cody Precord (2005-2012)\n\n"
        "usage: Editra [arguments] [files... ]\n\n"
        "Short Arguments:\n"
        "  -c    Set custom configuration directory at runtime\n"
