@@ -35,8 +35,8 @@ eclib.ctrlbox
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: finddlg.py 70025 2011-12-17 18:16:54Z CJP $"
-__revision__ = "$Revision: 70025 $"
+__svnid__ = "$Id: finddlg.py 70229 2012-01-01 01:27:10Z CJP $"
+__revision__ = "$Revision: 70229 $"
 
 __all__ = ["FindBox", "FindEvent", "FindPanel", "FindReplaceDlg",
            "MiniFindReplaceDlg", "AdvFindReplaceDlg",
@@ -179,6 +179,8 @@ class FindEvent(wx.PyCommandEvent):
     """
     def __init__(self, etype, eid=wx.ID_ANY, flags=0):
         """Creates the event object
+        @param etype: Event Type
+        @keyword eid: Event ID
         @keyword flags: Find/Replace flags
 
         """
