@@ -15,8 +15,8 @@ syntax highlighting of all supported filetypes.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_basestc.py 69268 2011-10-01 19:50:54Z CJP $"
-__revision__ = "$Revision: 69268 $"
+__svnid__ = "$Id: ed_basestc.py 70747 2012-02-29 01:33:35Z CJP $"
+__revision__ = "$Revision: 70747 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -305,15 +305,20 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
     def SetBlockCaret(self):
         """Change caret style to block"""
-        # XXX: This doesn't seem to be working with this wxPython version.
-#        self.SendMsg(msg=2512, lp=2)
-        # Alternatively, just make the caret a bit thicker!
-        self.SetCaretWidth(3)
+        if hasattr(self, 'SetCaretStyle'): # wxPython 2.9 or greater
+            self.SetCaretStyle(wx.stc.STC_CARETSTYLE_BLOCK)
+        else:
+            # Alternatively, just make the caret a bit thicker!
+            # best we can do on 2.8
+            self.SetCaretWidth(3)
 
     def SetLineCaret(self):
         """Change caret style to line"""
-        self.SetCaretWidth(1)
-#        self.SendMsg(2512, 1)
+        if hasattr(self, 'SetCaretStyle'):
+            self.SetCaretStyle(wx.stc.STC_CARETSTYLE_LINE)
+        else:
+            pwidth = Profile_Get('CARETWIDTH', default=1)
+            self.SetCaretWidth(pwidth)
 
     def BraceBadLight(self, pos):
         """Highlight the character at the given position
@@ -507,7 +512,6 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
     def DoZoom(self, mode):
         """Zoom control in or out
         @param mode: either zoom in or out
-        @type mode: int id value
 
         """
         id_type = mode
@@ -622,7 +626,6 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         @keyword line: optional if None current cursor position used
         @keyword col: optional if None current cursor position used
         @return: the command string to the left of the autocomp char
-        @todo: fillups are currently disabled. See note in Configure.
 
         """
         if None in (line, col):
@@ -630,27 +633,8 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             #       for multibyte characters.
             line, col = self.GetCurLine()
             col = self.GetColumn(self.GetCurrentPos())
-        line = line.expandtabs(self.GetTabWidth())
-        cmd_lmt = list(self._code['compsvc'].GetAutoCompStops() + \
-                       self._code['compsvc'].GetAutoCompFillups())
-        for key in self._code['compsvc'].GetAutoCompKeys():
-            kval = unichr(key)
-            if kval in cmd_lmt:
-                cmd_lmt.remove(kval)
-
-        curr_pos = col - 1
-        cmd = u''
-        while curr_pos > -1:
-            cmd = line[curr_pos:col]
-            if len(cmd) and cmd[0] not in cmd_lmt:
-                curr_pos -= 1
-            else:
-                break
-
-        for char in cmd_lmt:
-            cmd = cmd.replace(char, u'')
-
-        return cmd.strip()
+        cmd = self._code['compsvc'].GetCommandString(self, line, col)
+        return cmd
 
     def GetCommentChars(self):
         """Return the list of characters used to comment a string in the
@@ -715,14 +699,13 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
     def GetLangId(self):
         """Returns the language identifier of this control
         @return: language identifier of document
-        @rtype: int
 
         """
         return self._code['lang_id']
 
     def GetModTime(self):
         """Get the value of the buffers file last modtime"""
-        return self.file.GetModtime()
+        return self.file.ModTime
 
     def GetPos(self):
         """Update Line/Column information
@@ -760,6 +743,23 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         pos = max(0, pos-1)
         return 'comment' in self.FindTagById(self.GetStyleAt(pos))
 
+    def IsString(self, pos):
+        """Is the given position in a string region of the current buffer
+        @param pos: int position in buffer
+        @return: bool
+
+        """
+        style = self.GetStyleAt(pos)
+        return self.FindTagById(style) in ('string_style', 'char_style')
+
+    def IsNonCode(self, pos):
+        """Is the passed in position in a non code region
+        @param pos: buffer position
+        @return: bool
+
+        """
+        return self.IsComment(pos) or self.IsString(pos)
+
     def HasMarker(self, line, marker):
         """Check if the given line has the given marker set
         @param line: line number
@@ -774,7 +774,7 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         @return: bool
 
         """
-        sel = self.GetSelection()
+        sel = super(EditraBaseStc, self).GetSelection()
         return sel[0] != sel[1]
 
     def HasMultilineSelection(self):
@@ -783,7 +783,7 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
         """
         bMulti = False
-        sel = self.GetSelection()
+        sel = super(EditraBaseStc, self).GetSelection()
         if sel[0] != sel[1]:
             sline = self.LineFromPosition(sel[0])
             eline = self.LineFromPosition(sel[1])
@@ -826,15 +826,6 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             extend = Profile_Get('AUTO_COMP_EX') # Using extended autocomp?
             self._code['compsvc'] = autocomp.AutoCompService.GetCompleter(self, extend)
 
-    def IsString(self, pos):
-        """Is the given position in a string region of the current buffer
-        @param pos: int position in buffer
-        @return: bool
-
-        """
-        style = self.GetStyleAt(pos)
-        return self.FindTagById(style) in ('string_style', 'char_style')
-
     def LoadFile(self, path):
         """Load the file at the given path into the buffer. Returns
         True if no errors and False otherwise. To retrieve the errors
@@ -883,8 +874,7 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
     def OnChanged(self, evt):
         """Handles updates that need to take place after
         the control has been modified.
-        @param evt: event that called this handler
-        @type evt: wx.stc.StyledTextEvent
+        @param evt: wx.stc.StyledTextEvent
 
         """
         if self._line_num:
@@ -1076,6 +1066,33 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                     self.SetProperty(prop[0], prop[1])
         return True
 
+    def SetSelection(self, start, end):
+        """Override base method to make it work correctly using
+        Unicode character positions instead of UTF-8.
+
+        """
+        # STC HELL - some methods require UTF-8 offsets while others work
+        #            with Unicode...
+        # Calculate UTF-8 offsets in buffer
+        unicode_txt = self.GetText()
+        if start != 0:
+            start = len(unicode_txt[0:start].encode('utf-8'))
+        if end != 0:
+            end = len(unicode_txt[0:end].encode('utf-8'))
+        super(EditraBaseStc, self).SetSelection(start, end)
+
+    def GetSelection(self):
+        """Get the selection positions in Unicode instead of UTF-8"""
+        # STC HELL
+        # Translate the UTF8 byte offsets to unicode
+        start, end = super(EditraBaseStc, self).GetSelection()
+        utf8_txt = self.GetTextUTF8()
+        if start != 0:
+            start = len(utf8_txt[0:start].decode('utf-8'))
+        if end != 0:
+            end = len(utf8_txt[0:end].decode('utf-8'))
+        return start, end
+
     def ShowAutoCompOpt(self, command):
         """Shows the autocompletion options list for the command
         @param command: command to look for autocomp options for
